#[non_exhaustive]pub enum Error {
Show 13 variants
WindowNotFound,
ProcessNotFound {
pid: u32,
},
ProcessWindowNotFound {
pid: u32,
},
OverlayClosed,
TargetWindowLost,
WindowCreation(Error),
DeviceCreation,
SwapChainCreation,
ShaderCompilation {
message: String,
},
RenderTarget,
Renderer {
message: String,
},
DeviceLost {
reason: u32,
},
NoActiveFrame,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WindowNotFound
ProcessNotFound
ProcessWindowNotFound
OverlayClosed
TargetWindowLost
WindowCreation(Error)
DeviceCreation
SwapChainCreation
ShaderCompilation
RenderTarget
Renderer
DeviceLost
The graphics device was lost and could not be rebuilt.
A lost device is normally repaired during the next begin_frame without the
application seeing an error. This reports the case where the replacement device
could not be created, which usually means the adapter is gone for good.
NoActiveFrame