pub enum TextAlign {
Left,
Center,
Right,
}Expand description
Horizontal placement of a line relative to the position passed to the draw call.
Variants
Left
The position is the left edge of the line.
Center
The position is the horizontal center of the line.
Right
The position is the right edge of the line.