Crate procmod_overlay

Crate procmod_overlay 

Cross-platform game overlay rendering with transparent, click-through windows.

procmod-overlay creates a transparent overlay window on top of a target game window and provides an immediate-mode 2D drawing API for shapes, text, and game HUD elements.

Structs

Color
An RGBA color with 8-bit components.

Enums

Error

Type Aliases

Result